/*
 * man.c
 *
 * Created: 19.04.2017 14:40:08
 *  Author: dsosnowski
 */ 

#define F_CPU 8000000
#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include <inttypes.h>
#include "defs.h"
#include "buttons.h"
#include "man.h"
#include "disp.h"
#include "dstemp.h"
#include "settings.h"

#define MAN_BLINK_TIME_ON		55
#define MAN_BLINK_TIME_OFF		10


struct {
	uint8_t mode;
	uint8_t blink;
} manager;


//---------------------------------------------------------------
void ManKeyb(uint8_t button){
	uint8_t index;
	
	//--------------------------------------------------------------------------------------------
	if (manager.mode == MODE_STANDARD){
		if (button == BUTTON2_HOLD){
			manager.mode = MODE_SETT_ON;
			manager.blink = 0;
			button = 0;
		}
		if (button == BUTTON3_CLICK){
			manager.mode = MODE_VIEW_ON;
			manager.blink = 0;
		}
		if (button == BUTTON1_CLICK){
			manager.mode = MODE_VIEW_OFF;
			manager.blink = 0;
		}
	} 

	//--------------------------------------------------------------------------------------------
	if ((manager.mode == MODE_SETT_ON) || (manager.mode == MODE_SETT_OFF)){
		if ((button == BUTTON2_CLICK) || (button == BUTTON2_HOLD)){
			manager.mode++;
			manager.blink = 0;
			button = 0;
			if (manager.mode > MODE_SETT_OFF){
				manager.mode = MODE_STANDARD;
				DispDigitsSet(DIGIT_NULL_INDEX,DIGIT_NULL_INDEX,DIGIT_NULL_INDEX,DIGIT_NULL_VAL);
				_delay_ms(300);
				SettSave();
			}
		}		
		
		index = (manager.mode - 1);
		if (button == BUTTON3_CLICK){
			SettChange(index, 10);
		}
		if (button == BUTTON1_CLICK){
			SettChange(index, -10);
		}
		if (button == BUTTON3_HOLD){
			SettChange(index, 30);
		}
		if (button == BUTTON1_HOLD){
			SettChange(index, -30);
		}
	}
}

//---------------------------------------------------------------
void ManDisp(uint8_t mode){
	//static uint16_t blink;
	
	if ((mode == MODE_SETT_ON) || (mode == MODE_VIEW_ON)){
		manager.blink++;
		if (manager.blink > MAN_BLINK_TIME_OFF) {
			DispTemp(SettValGet(0));
		} else {
			DispDigitsSet(DIGIT_NULL_INDEX,DIGIT_NULL_INDEX,DIGIT_NULL_INDEX,DIGIT_NULL_VAL);
		}		
	}

	if ((mode == MODE_SETT_OFF) || (mode == MODE_VIEW_OFF)){
		manager.blink++;
		if (manager.blink > MAN_BLINK_TIME_OFF) {
			DispTemp(SettValGet(1));
		} else {
			DispDigitsSet(DIGIT_NULL_INDEX,DIGIT_NULL_INDEX,DIGIT_NULL_INDEX,DIGIT_NULL_VAL);
		}
	}

	if (manager.blink > MAN_BLINK_TIME_ON) {
		if ((mode == MODE_VIEW_ON) || (mode == MODE_VIEW_OFF)){
			manager.mode = MODE_STANDARD;			
		}
		manager.blink = 0;
	}
}

//---------------------------------------------------------------
uint8_t ManModeGet(void){
	return manager.mode;
}
